@@ -172,8 +172,6 @@ gcm_parser_load_icc_vcgt_formula (GcmProfileLcms1 *profile_lcms1, const guint8 *
 	gboolean ret = FALSE;
 	GcmClutData *vcgt_data;
 
-	egg_debug ("loading a formula encoded gamma table");
-
 	/* just load in data into a temporary array */
 	profile_lcms1->priv->vcgt_data = g_new0 (GcmClutData, 4);
 	vcgt_data = profile_lcms1->priv->vcgt_data;
@@ -226,8 +224,6 @@ gcm_parser_load_icc_vcgt_table (GcmProfileLcms1 *profile_lcms1, const guint8 *da
 	guint i;
 	GcmClutData *vcgt_data;
 
-	egg_debug ("loading a table encoded gamma table");
-
 	num_channels = gcm_parser_decode_16 (data + GCM_VCGT_TABLE_NUM_CHANNELS);
 	num_entries = gcm_parser_decode_16 (data + GCM_VCGT_TABLE_NUM_ENTRIES);
 	entry_size = gcm_parser_decode_16 (data + GCM_VCGT_TABLE_NUM_SIZE);
@@ -240,10 +236,6 @@ gcm_parser_load_icc_vcgt_table (GcmProfileLcms1 *profile_lcms1, const guint8 *da
 		num_channels = 3;
 	}
 
-	egg_debug ("channels: %u", num_channels);
-	egg_debug ("entry size: %ubits", entry_size * 8);
-	egg_debug ("entries/channel: %u", num_entries);
-
 	/* only able to parse RGB data */
 	if (num_channels != 3) {
 		egg_warning ("cannot parse non RGB entries");
@@ -389,7 +381,6 @@ gcm_profile_lcms1_parse_multi_localized_unicode (GcmProfileLcms1 *profile_lcms1,
 			/* there is more than one language encoded */
 			egg_warning ("more than one item of data in MLUC (names size: %i), using first one", names_size);
 		}
-		record_size = gcm_parser_decode_32 (data + 12);
 		len = gcm_parser_decode_32 (data + 20);
 		offset_name = gcm_parser_decode_32 (data + 24);
 		text = gcm_profile_lcms1_utf16be_to_locale (data + offset_name, len);
@@ -651,8 +642,6 @@ gcm_profile_lcms1_parse_data (GcmProfile *profile, const guint8 *data, gsize len
 
 	/* get the number of tags in the file */
 	num_tags = gcm_parser_decode_32 (data + GCM_NUMTAGS);
-	egg_debug ("number of tags: %i", num_tags);
-
 	for (i=0; i<num_tags; i++) {
 		offset = GCM_TAG_WIDTH * i;
 		tag_id = gcm_parser_decode_32 (data + GCM_BODY + offset + GCM_TAG_ID);
@@ -683,7 +672,6 @@ gcm_profile_lcms1_parse_data (GcmProfile *profile, const guint8 *data, gsize len
 			g_free (text);
 		}
 		if (tag_id == icSigMachineLookUpTableTag) {
-			egg_debug ("found MLUT which is a fixed size block");
 			ret = gcm_parser_load_icc_mlut (profile_lcms1, data + tag_offset, tag_size);
 			if (!ret) {
 				g_set_error_literal (error, 1, 0, "failed to load mlut");
@@ -691,7 +679,6 @@ gcm_profile_lcms1_parse_data (GcmProfile *profile, const guint8 *data, gsize len
 			}
 		}
 		if (tag_id == icSigVideoCartGammaTableTag) {
-			egg_debug ("found VCGT");
 			if (tag_size == 1584)
 				priv->adobe_gamma_workaround = TRUE;
 			ret = gcm_parser_load_icc_vcgt (profile_lcms1, data + tag_offset, tag_size);
@@ -707,10 +694,6 @@ gcm_profile_lcms1_parse_data (GcmProfile *profile, const guint8 *data, gsize len
 
 	/* set properties */
 	gcm_profile_set_has_vcgt (profile, priv->has_vcgt_formula || priv->has_vcgt_table);
-
-	egg_debug ("Has MLUT:         %s", priv->has_mlut ? "YES" : "NO");
-	egg_debug ("Has VCGT formula: %s", priv->has_vcgt_formula ? "YES" : "NO");
-	egg_debug ("Has VCGT table:   %s", priv->has_vcgt_table ? "YES" : "NO");
 out:
 	return ret;
 }
